<?php

namespace Insallah;
class TournamentModel
{

    /**
     * проверка уровня, стоимости эквипа, прочие проверки, что персонаж свободен
     * таймер ожидания 30 минут
     *
     * @param int $uid
     *
     * @return int
     */
    public static function getUserLevel($uid)
    {
        $db = new Db;
        $level = $db::getValue('select level from users where id = ? and level between 8 and 12 and battle = 0', [$uid]);
        if (!$level) {
            return 0;
        }
        $ekr_total = $db::getValue('select sum(2price) from items_users where inOdet > 0 and uid = ?', [$uid]);
        $exp = $db::getValue('select exp from stats where id = ?', [$uid]);
        // Вот правда не знаю проканает или нет.
        if ($ekr_total > ($level - 7) * 150 || $exp < 250000) {
            return 0;
        }
        return $level;
    }

    /**
     * Считаем сколько игроков ждут в заявке на турнир.
     *
     * @param int $tid
     *
     * @return int
     */
    public static function getWaitingMembersQuantity($tid)
    {
        $db = new Db();
        return $db::getValue('select count(*) from tournaments_users where tid = ?', [$tid]);
    }

    /**
     * Создание нового турнира.
     *
     * @param int $tid
     *
     * @return void
     */
    public static function createTournament($tid)
    {
        $db = new Db();
        $db::sql('insert into tournaments (tid) values (?)', [$tid]);
    }

    /**
     * Игрок присоединяется к турниру и телепортируется в турнирную комнату.
     *
     * @param int $uid
     * @param int $tid
     *
     * @return void
     */
    public static function joinTournament($uid, $tid)
    {
        /** Кастомные комнаты 25008 - 25012. */
        $room_id = 25000 + $tid;
        $db = new Db();
        $db::sql('insert into tournaments_users (tid, uid) values (?, ?)', [$tid, $uid]);
        self::teleport($uid, $room_id);
    }

    /**
     * Старт турнира.
     *
     * @param int $tid
     *
     * @return void
     */
    public static function startTournament($tid)
    {
        $db = new Db();
        $db::sql('update tournaments set start_time = -1 where tid = ?', [$tid]);
    }

    /**
     * Чистим базы от прошедшего турнира.
     *
     * @param int $tid
     *
     * @return void
     */
    public static function destroyTournament($tid)
    {
        $db = new Db();
        //Убедиться что в базе настроен foreign_keys и последует автоочистка tournaments_users !!!
        $db::sql('delete from tournaments where tid = ?', [$tid]);
    }

    /**
     * Получаем список бойцов и бьём их на пары. Возвращаем списки пар + 1 последний без пары если есть.
     *
     * @param array $fighters_list
     *
     * @return array
     */
    public static function getFightersTeams(array $fighters_list)
    {
        $db = new Db();
        return array_chunk($db::getRows('select id from users where battle = 0 and id in (?)', [implode(', ', $fighters_list)]), 2);
    }

    /**
     * Выбираем живых бойцов не сражающихся в данный момент.
     *
     * @param int $tid
     *
     * @return array
     */
    public static function getFreeFighters($tid)
    {
        $db = new Db();
        return $db::getRows('select uid from tournaments_users where tid = ? and death_time = 0 order by rand()', [$tid]);
    }

    /**
     * Выбираем победителей. Смещаем массив, чтобы возврат шёл с единицы.
     *
     * @param int $tid
     *
     * @return array
     */
    public static function getWinners($tid)
    {
        $db = new Db();
        $arr = [];
        array_unshift($arr, '');
        unset($arr[0]);
        $winners = $db::getRows('select uid from tournaments_users where tid = ? order by death_time desc limit 3', [$tid]);
        foreach ($winners as $winner) {
            $arr[] = $winner['uid'];
        }
        return $arr;
    }

    /**
     * Пробуем выкусить проигравшего в последней турнирной битве и удалить эту самую битву во избежание.
     * @return mixed
     */
    public static function getLooser()
    {
        $query = '
            select uid, battle 
            from 
                battle_users, 
                (select id, team_win 
                 from battle 
                 where 
                     team_win > 0 and 
                     typeBattle = 25000 
                 order by time_over desc 
                 limit 1) as last_battle 
            where 
                battle_users.battle = last_battle.id and 
                battle_users.team != last_battle.team_win';
        $db = new Db;
        $row = $db::getRow($query);
        $db::sql('delete from battle where id = ?', [$row['battle']]);
        return $row['uid'];
    }

    /**
     * Выбывший из турнира покидает комнату и получает время смерти.
     *
     * @param int $uid
     *
     * @return void
     */
    public static function removeFighter($uid)
    {
        $db = new Db();
        $db::sql('update tournaments_users set death_time = unix_timestamp() where uid = ?', [$uid]);
        self::teleport($uid, 9);
    }

    /**
     * Узнаём id турнира по id игрока.
     * todo Проверить, возможно можно обращаться к уровню игрока.
     *
     * @param int $uid
     *
     * @return mixed
     */
    public static function getTournamentIdByUserId($uid)
    {
        $db = new Db();
        return $db::getValue('select tid from tournaments_users where uid = ?', [$uid]);
    }

    /**
     * Попробуем стартонуть поединок.
     * 25000 - Уникальный id поединка под турниры.
     * noinc - запрет на вмешательство
     * invis - невидимый бой
     *
     * @param int $uid1
     * @param int $uid2
     *
     * @return void
     */
    public static function startBattle($uid1, $uid2)
    {
        $db = new Db();
        $db::exec('insert into battle (city, time_start, timeout, type, invis, noinc, travmChance, typeBattle) 
        values (\'capitalcity\', unix_timestamp(), 60, 0, 1, 1, 0, 25000)');
        $db::sql('update stats set team = 1, hpNow = hpAll, mpNow = mpAll where id = ?', [$uid1]);
        $db::sql('update stats set team = 2, hpNow = hpAll, mpNow = mpAll where id = ?', [$uid2]);
        $db::sql('update users set battle = ? where id in (?, ?)', [$db::lastInsertId(), $uid1, $uid2]);
    }

    /**
     * Узнаём логин персонажа по его id.
     *
     * @param int $uid
     *
     * @return mixed
     */
    public static function uidToLogin($uid)
    {
        $db = new Db();
        return $db::getValue('select login from users where id = ?', [$uid]);
    }

    /**
     * Телепорт по комнатам.
     *
     * @param int $uid
     * @param int $room_id
     *
     * @return void
     */
    private static function teleport($uid, $room_id)
    {
        $db = new Db();
        $db::sql('update users set room = ? where id = ?', [$room_id, $uid]);
    }

    /**
     * Нет проверок $message потому что оно всегда задаётся в коде и игрок на него не влияет.
     *
     * @param string $city
     * @param string $message
     *
     * @return void
     */
    public static function sysMessage($message, $city = 'capitalcity')
    {
        $db = new Db();
        $db::sql('insert into chat (city, room, time, type, text, new, da) values (?, 0, unix_timestamp(), 6, ?, 1, 1)', [$city, $message]);
    }

    /**
     * Генерирует множественный запрос сразу на $quantity однотипных предметов в инвентарь пользователя $uid.
     *
     * @param int $uid
     * @param int $quantity
     *
     * @return void
     */
    public static function givePrizeItems($uid, $quantity)
    {
        $query = 'insert into items_users (item_id, uid, data, iznosMAX, lastUPD, time_create) 
                    values (4754, :uid, :data, 1, unix_timestamp(), unix_timestamp())';
        $args = [
            'uid' => $uid,
            'data' => 'nosale=1|musor=1|sudba=' . self::uidToLogin($uid) . '|lvl=8|tr_s1=0|tr_s2=0|tr_s3=0|tr_s4=0'
        ];
        $db = new Db();
        $stmt = $db::prepare($query);
        for ($i = 0; $i < $quantity; $i++) {
            $stmt->execute($args);
        }
    }
}